@@ -1,5 +1,5 @@
 cGroupsWUI <- function(port = 8102L){
-  assign("runAppLocal", value=TRUE, envir=as.environment("package:compareGroups"))
+  #assign("runAppLocal", value=TRUE, envir=as.environment("package:compareGroups"))
   # environment(runAppLocal) <- as.environment("package:compareGroups")
   shiny::runApp(system.file("app", package="compareGroups"), port)
 }
\ No newline at end of file
