@@ -1,4 +1,4 @@
-export2html<-function(x, file, which.table="descr", nmax=TRUE, header.labels=c(), ...){
+export2html<-function(x, file, which.table="descr", nmax=TRUE, nmax.method=1, header.labels=c(), ...){
     if (!inherits(x, "createTable")) 
         stop("x must be of class 'createTable'")
     if (inherits(x, "cbind.createTable")) 
@@ -7,8 +7,8 @@ export2html<-function(x, file, which.table="descr", nmax=TRUE, header.labels=c()
     if (is.na(ww)) 
         stop(" argument 'which.table' must be either 'descr', 'avail' or 'both'")
     if (ww %in% c(1, 3)) {
-        pp <- prepare(x, nmax = nmax, header.labels)
-        table1 <- prepare(x, nmax = nmax, header.labels)[[1]]
+        pp <- prepare(x, nmax = nmax,nmax.method=nmax.method, header.labels)
+        table1 <- prepare(x, nmax = nmax,nmax.method=nmax.method, header.labels)[[1]]
         cc <- unlist(attr(pp, "cc"))
         ii <- ifelse(rownames(table1)[2] == "", 2, 1)
         table1 <- cbind(rownames(table1), table1)
@@ -45,7 +45,7 @@ export2html<-function(x, file, which.table="descr", nmax=TRUE, header.labels=c()
         }
     }
     if (ww %in% c(2, 3)) {
-        table2 <- prepare(x, nmax = nmax, c())[[2]]
+        table2 <- prepare(x, nmax = nmax,nmax.method=nmax.method, c())[[2]]
         table2 <- cbind(rownames(table2), table2)
           if (!is.null(attr(x, "caption"))) {
             cc <- unlist(attr(x, "caption"))
