@@ -18,9 +18,9 @@ function (object, formula., ..., evaluate = TRUE)
     
     if (!missing(formula.)){
       if (inherits(formula., "formula")){ 
-        if (inherits(eval(call$formula), "formula"))
+        if (inherits(eval(call$formula), "formula")){
           call$formula <- update.formula2(call$formula, formula.)
-        else {
+        }else {
           call$data <- call$formula
           call$formula <- formula.
         }
