@@ -29,10 +29,13 @@ source("flipBox.R")
 
 
 #if (!runAppLocal){
+if (dir.exists(".secrets")){
   # insert entires logs
   sheet_id <- "https://docs.google.com/spreadsheets/d/11nVz8IjpLTwSJUDPK8uG5yG_rfNWc3nK6pE-TKx84BY/"
   gs4_auth(cache = ".secrets", email = "isubirana@datarus.eu", subject = "isubirana@datarus.eu",scope="spreadsheets", use_oob = TRUE)
-#}
+} else {
+  print("Running app from cGroupsWUI()")
+}
 
 
 data(regicor); data(SNPs)
